# Generated by ariadne-codegen
# Source: operations.graphql

from typing import Optional

from stigg._vendors.pydantic import Field

from .base_model import BaseModel
from .fragments import CustomerStatisticsFragment


class GetCustomerStatistics(BaseModel):
    get_customer_by_ref_id: Optional["GetCustomerStatisticsGetCustomerByRefId"] = Field(
        alias="getCustomerByRefId"
    )


class GetCustomerStatisticsGetCustomerByRefId(CustomerStatisticsFragment):
    pass


GetCustomerStatistics.model_rebuild()
